<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<gui version="3" name="kipiplugin_flickr" >
<!-- NOTE: don't forget to increase version ID when this file is modified -->

    <MenuBar>

        <Menu name="Export"><text>&amp;Export</text>
            <Action name="flickrexport" group="kipi_export_group" />
            <Action name="23export" group="kipi_export_group" />
        </Menu>

    </MenuBar>

    <ToolBar name="mainToolBar"><text>Main Toolbar</text>
    </ToolBar>

</gui>

