<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<gui version="2" name="kipiplugin_printimages" >
<!-- NOTE: don't forget to increase version ID when this file is modified -->

    <MenuBar>

        <Menu name="Image"><text>&amp;Image</text>
            <Action name="printimages" group="kipi_image_group" />
            <Action name="printassistant" group="kipi_image_group" />
        </Menu>

    </MenuBar>

    <ToolBar name="mainToolBar"><text>Main Toolbar</text>
    </ToolBar>

</gui>
